API
===

.. autofunction:: triangle.triangulate

.. autofunction:: triangle.convex_hull

.. autofunction:: triangle.delaunay

.. autofunction:: triangle.voronoi

.. autofunction:: triangle.get_data

.. autofunction:: triangle.loads

.. autofunction:: triangle.load
